- city
(character, optional) The city of publication. Default is NULL.
- ddk
(character, optional) The Dewey Decimal Classification (DDC) code. Default is NULL.
- lang
(character, optional) The language code of the books. Default is NULL.
- period
(list, optional) A list containing the start and end years of the period to search. Default is an empty list.
- publisher
(character, optional) The publisher's name. Default is NULL.
- title
(character, optional) The title or a part of the title of the books. Default is NULL.
- topic
(character, optional) A topic or subject associated with the books. Default is NULL.
- word
(list, optional) A list of words (ngrams) to search for in the books. Default is list("hus", "blokk").